summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-11-04 01:13:02 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-11-04 01:13:02 -0500
commitf2d05b6e3332cf2d6488a85c3389ef9100ff580d (patch)
treeafaa6e55941a771cdbfdf51424e03e94913b8040
parentaa0e597d69c5fee77817b37b89407137893b3baf (diff)
downloadkoffice-f2d05b6e3332cf2d6488a85c3389ef9100ff580d.tar.gz
koffice-f2d05b6e3332cf2d6488a85c3389ef9100ff580d.zip
Fix references to user profile directory.
-rw-r--r--chalk/ui/kis_custom_brush.cc2
-rw-r--r--chalk/ui/kis_custom_palette.cc2
-rw-r--r--chalk/ui/kis_custom_pattern.cc2
-rw-r--r--doc/kspread/faq.docbook2
-rw-r--r--kexi/plugins/scripting/scripts/copycenter/readme.html2
-rw-r--r--kexi/tools/add_column/kexi_add_column_gui2
-rwxr-xr-xkexi/tools/delete_column/kexi_delete_column_gui2
-rwxr-xr-xkpresenter/scripts/mkstandalone.sh14
-rw-r--r--lib/kofficecore/KoDocument.cpp4
9 files changed, 16 insertions, 16 deletions
diff --git a/chalk/ui/kis_custom_brush.cc b/chalk/ui/kis_custom_brush.cc
index d633935c..34289f3e 100644
--- a/chalk/ui/kis_custom_brush.cc
+++ b/chalk/ui/kis_custom_brush.cc
@@ -80,7 +80,7 @@ void KisCustomBrush::slotExport() {
}
void KisCustomBrush::slotAddPredefined() {
- // Save in the directory that is likely to be: ~/.kde/share/apps/chalk/brushes
+ // Save in the directory that is likely to be: ~/.trinity/share/apps/chalk/brushes
// a unique file with this brushname
TQString dir = KGlobal::dirs()->saveLocation("data", "chalk/brushes");
TQString extension;
diff --git a/chalk/ui/kis_custom_palette.cc b/chalk/ui/kis_custom_palette.cc
index ac762953..f12b9300 100644
--- a/chalk/ui/kis_custom_palette.cc
+++ b/chalk/ui/kis_custom_palette.cc
@@ -119,7 +119,7 @@ void KisCustomPalette::slotAddPredefined() {
m_palette->setName(palettename->text());
if (!m_editMode) {
- // Save in the directory that is likely to be: ~/.kde/share/apps/chalk/palettes
+ // Save in the directory that is likely to be: ~/.trinity/share/apps/chalk/palettes
// a unique file with this palettename
TQString dir = KGlobal::dirs()->saveLocation("data", "chalk/palettes");
TQString extension;
diff --git a/chalk/ui/kis_custom_pattern.cc b/chalk/ui/kis_custom_pattern.cc
index 4f0821ed..538ec9c6 100644
--- a/chalk/ui/kis_custom_pattern.cc
+++ b/chalk/ui/kis_custom_pattern.cc
@@ -78,7 +78,7 @@ void KisCustomPattern::slotAddPredefined() {
if (!m_pattern)
return;
- // Save in the directory that is likely to be: ~/.kde/share/apps/chalk/patterns
+ // Save in the directory that is likely to be: ~/.trinity/share/apps/chalk/patterns
// a unique file with this pattern name
TQString dir = KGlobal::dirs()->saveLocation("data", "chalk/patterns");
TQString extension;
diff --git a/doc/kspread/faq.docbook b/doc/kspread/faq.docbook
index c8687449..83ae158f 100644
--- a/doc/kspread/faq.docbook
+++ b/doc/kspread/faq.docbook
@@ -25,7 +25,7 @@
<question><para>Where are the templates stored?</para>
</question>
<answer><para>As <literal role="extension">.kst</literal> files under
-<filename>~/.kde/share/apps/kspread/templates/</filename>.
+<filename>~/.trinity/share/apps/kspread/templates/</filename>.
</para></answer>
</qandaentry>
diff --git a/kexi/plugins/scripting/scripts/copycenter/readme.html b/kexi/plugins/scripting/scripts/copycenter/readme.html
index 2aff6152..09deb028 100644
--- a/kexi/plugins/scripting/scripts/copycenter/readme.html
+++ b/kexi/plugins/scripting/scripts/copycenter/readme.html
@@ -9,7 +9,7 @@ plugin-architecture allows transparent copies between different backends.</p>
<ul>
<li>Read+write Kexi Databases. This includes all database backends supported by Kexi (like SQLite, MySQL or PostgreSQL).</li>
<li>Read+write QtSQL Databases. MySQL, PostgreSQL and UnixODBC are supported. There might even be more like Oracle in the commercial Qt version or 3rd party backends.</li>
-<li>Runs embedded in Kexi (from the tools=>scripts menu) as well as independent of Kexi (use "krossrunner ~/.kde/share/apps/kexi/scripts/copycenter/CopyCenter.py" or python direct).</li>
+<li>Runs embedded in Kexi (from the tools=>scripts menu) as well as independent of Kexi (use "krossrunner ~/.trinity/share/apps/kexi/scripts/copycenter/CopyCenter.py" or python direct).</li>
<li>Depends only on PyQt. PyKDE is not used at all and Kross (included in KOffice 1.5) is optional.</li>
</ul>
diff --git a/kexi/tools/add_column/kexi_add_column_gui b/kexi/tools/add_column/kexi_add_column_gui
index 211a2fe9..da163d96 100644
--- a/kexi/tools/add_column/kexi_add_column_gui
+++ b/kexi/tools/add_column/kexi_add_column_gui
@@ -21,7 +21,7 @@
basedir=`dirname "$0"`
setup_messages {
- lang=`grep Language= ~/.kde/share/config/kdeglobals | head -n 1 | \
+ lang=`grep Language= ~/.trinity/share/config/kdeglobals | head -n 1 | \
sed -e 's/Language=\(.*\):.*/\1/'`
if [ -z "$lang" ] ; then lang="en" ; fi
diff --git a/kexi/tools/delete_column/kexi_delete_column_gui b/kexi/tools/delete_column/kexi_delete_column_gui
index 545c9b5e..73cd1d40 100755
--- a/kexi/tools/delete_column/kexi_delete_column_gui
+++ b/kexi/tools/delete_column/kexi_delete_column_gui
@@ -21,7 +21,7 @@
basedir=`dirname "$0"`
setup_messages {
- lang=`grep Language= ~/.kde/share/config/kdeglobals | head -n 1 | \
+ lang=`grep Language= ~/.trinity/share/config/kdeglobals | head -n 1 | \
sed -e 's/Language=\(.*\):.*/\1/'`
if [ -z "$lang" ] ; then lang="en" ; fi
diff --git a/lib/kofficecore/KoDocument.cpp b/lib/kofficecore/KoDocument.cpp
index a54cfc25..6abf8083 100644
--- a/lib/kofficecore/KoDocument.cpp
+++ b/lib/kofficecore/KoDocument.cpp
@@ -2231,8 +2231,8 @@ KService::Ptr KoDocument::readNativeService( KInstance *instance )
// The old way is kept as fallback for compatibility, but in theory this is really never used anymore.
// Try by path first, so that we find the global one (which has the native mimetype)
- // even if the user created a kword.desktop in ~/.kde/share/applnk or any subdir of it.
- // If he created it under ~/.kde/share/applnk/Office/ then no problem anyway.
+ // even if the user created a kword.desktop in ~/.trinity/share/applnk or any subdir of it.
+ // If he created it under ~/.trinity/share/applnk/Office/ then no problem anyway.
service = KService::serviceByDesktopPath( TQString::fromLatin1("Office/%1.desktop").arg(instname) );
}
if ( !service )
diff --git a/kpresenter/scripts/mkstandalone.sh b/kpresenter/scripts/mkstandalone.sh
index b362ee36..fa99fe69 100755
--- a/kpresenter/scripts/mkstandalone.sh
+++ b/kpresenter/scripts/mkstandalone.sh
@@ -25,8 +25,8 @@ else
cp -r $TDEDIR/share/apps/kstyle $out/share/apps/
mkdir -p $out/share/config
cp $TDEDIR/share/config/kdebug.areas $out/share/config/
- cp ~/.kde/share/config/kdeglobals $out/share/config/
- cp ~/.kde/share/config/kpresenterrc $out/share/config/
+ cp ~/.trinity/share/config/kdeglobals $out/share/config/
+ cp ~/.trinity/share/config/kpresenterrc $out/share/config/
### cp $TDEDIR/share/icons $out/share/
cp -r $TDEDIR/share/toolbar $out/share/
mkdir -p $out/share/servicetypes
@@ -72,17 +72,17 @@ else
cp $TDEDIR/bin/kpresenter $out/bin/
cp $TDEDIR/bin/dcopserver $out/bin/
# Take kded as well - we could copy the ksycoca file but we would have
# to install it in ~/.kde ...
cp $TDEDIR/bin/kded $out/bin/
########### Startup script
echo '#!/bin/sh' > $out/go.sh
echo 'export TDEDIR=`pwd`' >> $out/go.sh
echo 'export LD_LIBRARY_PATH=$TDEDIR/lib' >> $out/go.sh
- echo 'mkdir -p ~/.kde 2>/dev/null' >> $out/go.sh
- echo 'mkdir -p ~/.kde/share 2>/dev/null' >> $out/go.sh
- echo 'mkdir -p ~/.kde/share/config 2>/dev/null' >> $out/go.sh
- echo 'cp share/config/* ~/.kde/share/config' >> $out/go.sh
+ echo 'mkdir -p ~/.trinity 2>/dev/null' >> $out/go.sh
+ echo 'mkdir -p ~/.trinity/share 2>/dev/null' >> $out/go.sh
+ echo 'mkdir -p ~/.trinity/share/config 2>/dev/null' >> $out/go.sh
+ echo 'cp share/config/* ~/.trinity/share/config' >> $out/go.sh
echo 'bin/dcopserver 2>/dev/null' >> $out/go.sh
echo 'sleep 1 ; bin/kded 2>/dev/null' >> $out/go.sh
echo 'sleep 1 ; bin/kpresenter $* 1>/dev/null 2>kpresenter.out &' >> $out/go.sh
@@ -72,17 +72,17 @@ else
cp $TDEDIR/bin/dcopserver $out/bin/
# Take kded as well - we could copy the ksycoca file but we would have
- # to install it in ~/.kde ...
+ # to install it in ~/.trinity ...
cp $TDEDIR/bin/kded $out/bin/
########### Startup script